==> indigitall_flutter_plugin-1.4.0.tar.gz: lib/inapp/models/InApp.dart <==
import 'InAppProperties.dart';
import 'InAppSchema.dart';

class InApp {
  /// String field name inAppId
  static const String _INAPPID = "inAppId";

  /// String field name last version Id
  static const String _LAST_VERSION_ID = "lastVersionId";

  /// String field name show once
  static const String _SHOW_ONCE = "showOnce";

  /// String field name renewal time
  static const String _RENEWAL_TIME = "renewalTime";

  /// String field name creation date
  static const String _CREATION_DATE = "creationDate";

  /// String field name expired date
  static const String _EXPIRED_DATE = "expiredDate";

  /// String field properties model
  static const String _PROPERTIES = InAppProperties.PROPERTIES;

  /// String field name schema model
  static const String _SCHEMA = InAppSchema.SCHEMA;

  /// id of inApp
  int? inAppId;

  ///last version id of inApp
  int? lastVersionId;

  ///if inapp show once
  bool? showOnce;

  /// creation date of inApp
  String? creationDate;

  /// expired date of inApp
  String? expiredDate;

  /// properties model of inApp
  InAppProperties? properties;

  /// renewal time
  String? renewalTime;

  /// schema model of inApp
  InAppSchema? schema;

  /// Constructor of [InApp]
  InApp(Map map) {
    map.forEach((key, value) {
      switch (key) {
        case _INAPPID:
          inAppId = int.parse(value.toString());
          break;
        case _LAST_VERSION_ID:
          lastVersionId = int.parse(value.toString());
          break;
        case _SHOW_ONCE:
          showOnce = value.toString() == "true";
          break;
        case _RENEWAL_TIME:
          renewalTime = value.toString();
          break;
        case _CREATION_DATE:
          creationDate = value.toString();
          break;
        case _EXPIRED_DATE:
          expiredDate = value.toString();
          break;
        case _PROPERTIES:
          properties = InAppProperties(value);
          break;
        case _SCHEMA:
          schema = InAppSchema(value);
          break;
      }
    });
  }

  /// Conversion InApp to Map
  Map toMap() {
    Map map = Map();
    if (inAppId != null) map[_INAPPID] = inAppId;
    if (lastVersionId != null) map[_LAST_VERSION_ID] = lastVersionId;
    if (showOnce != null) map[_SHOW_ONCE] = showOnce;
    if (renewalTime != null) map[_RENEWAL_TIME] = renewalTime;
    if (creationDate != null) map[_CREATION_DATE] = creationDate;
    if (expiredDate != null) map[_EXPIRED_DATE] = expiredDate;
    if (properties != null) map[_PROPERTIES] = properties!.toMap();
    if (schema != null) map[_SCHEMA] = schema!.toMap();
    return map;
  }
}

==> indigitall_flutter_plugin-2.0.2.tar.gz: lib/inapp/models/InApp.dart <==
import 'InAppProperties.dart';
import 'InAppSchema.dart';

class InApp {
  /// String field name inAppId
  static const String _INAPPID = "inAppId";

  /// String field name last version Id
  static const String _LAST_VERSION_ID = "lastVersionId";

  /// String field name show once
  static const String _SHOW_ONCE = "showOnce";

  /// String field name version
  static const String _VERSION = "version";

  /// String field name cacheTtl
  static const String _CACHE_TTL = "cacheTtl";

  /// String field name customData
  static const String _CUSTOM_DATA = "customData";

  /// String field name creation date
  static const String _CREATION_DATE = "creationDate";

  /// String field name expired date
  static const String _EXPIRED_DATE = "expiredDate";

  /// String field properties model
  static const String _PROPERTIES = InAppProperties.PROPERTIES;

  /// String field name schema model
  static const String _SCHEMA = InAppSchema.SCHEMA;

  /// id of inApp
  int? inAppId;

  ///last version id of inApp
  int? lastVersionId;

  ///if inapp show once
  bool? showOnce;

  /// creation date of inApp
  String? creationDate;

  /// expired date of inApp
  String? expiredDate;

  /// properties model of inApp
  InAppProperties? properties;

  /// version
  int? version;

  /// cache ttl
  int? cacheTtl;

  ///customData
  String? customData;

  /// schema model of inApp
  InAppSchema? schema;

  /// Constructor of [InApp]
  InApp(Map map) {
    map.forEach((key, value) {
      switch (key) {
        case _INAPPID:
          inAppId = int.parse(value.toString());
          break;
        case _LAST_VERSION_ID:
          lastVersionId = int.parse(value.toString());
          break;
        case _SHOW_ONCE:
          showOnce = value.toString() == "true";
          break;
        case _CACHE_TTL:
          cacheTtl = int.parse(value.toString());
          break;
        case _CUSTOM_DATA:
          customData = value.toString();
          break;
        case _VERSION:
          version = int.parse(value.toString());
          break;
        case _CREATION_DATE:
          creationDate = value.toString();
          break;
        case _EXPIRED_DATE:
          expiredDate = value.toString();
          break;
        case _PROPERTIES:
          properties = InAppProperties(value);
          break;
        case _SCHEMA:
          schema = InAppSchema(value);
          break;
      }
    });
  }

  /// Conversion InApp to Map
  Map toMap() {
    Map map = Map();
    if (inAppId != null) map[_INAPPID] = inAppId;
    if (lastVersionId != null) map[_LAST_VERSION_ID] = lastVersionId;
    if (showOnce != null) map[_SHOW_ONCE] = showOnce;
    if (version != null) map[_VERSION] = version;
    if (cacheTtl != null) map[_CACHE_TTL] = cacheTtl;
    if (customData != null) map[_CUSTOM_DATA] = customData;
    if (creationDate != null) map[_CREATION_DATE] = creationDate;
    if (expiredDate != null) map[_EXPIRED_DATE] = expiredDate;
    if (properties != null) map[_PROPERTIES] = properties!.toMap();
    if (schema != null) map[_SCHEMA] = schema!.toMap();
    return map;
  }
}
